@@ -1,9 +1,14 @@
-from traitsui.menu import (OKButton, CancelButton, OKCancelButtons)
+from packaging.version import Version
+
+import traitsui
 import traitsui.api as tu
+from traitsui.menu import OKButton, CancelButton, OKCancelButtons
 
-from hyperspy_gui_traitsui.buttons import *
-from hyperspy_gui_traitsui.utils import add_display_arg
 from hyperspy_gui_traitsui.axes import get_navigation_sliders_group
+from hyperspy_gui_traitsui.buttons import (
+    OurApplyButton,HelpButton, OurResetButton
+    )
+from hyperspy_gui_traitsui.utils import add_display_arg
 
 
 class SmoothingHandler(tu.Handler):
@@ -17,14 +22,46 @@ class SmoothingHandler(tu.Handler):
         return True
 
 
+class LineSelectorInSignal2DHandler(tu.Handler):
+    def close(self, info, is_ok):
+        info.object.on = False
+        if is_ok is True:
+            self.apply(info)
+
+        return True
+
+    def close_directly(self, info):
+        if (info.ui.owner is not None) and self.close(info, False):
+            info.ui.owner.close()
+
+    def apply(self, info, *args, **kwargs):
+        """Handles the **Apply** button being clicked."""
+        obj = info.object
+        obj.is_ok = True
+        if hasattr(obj, "apply"):
+            obj.apply()
+        return
+
+    def next(self, info, *args, **kwargs):
+        """Handles the **Next** button being clicked."""
+        obj = info.object
+        obj.is_ok = True
+        if hasattr(obj, "next"):
+            next(obj)
+        return
+
+
 class SpanSelectorInSignal1DHandler(tu.Handler):
 
     def close(self, info, is_ok):
         # Removes the span selector from the plot
         obj = info.object
-        obj.span_selector_switch(False)
+
+        # Apply before switching off the selector
         if is_ok is True:
             self.apply(info)
+        obj.span_selector_switch(False)
+
         if hasattr(obj, 'close'):
             obj.close()
 
@@ -59,10 +96,12 @@ class SpanSelectorInSignal1DHandler(tu.Handler):
 class Signal1DRangeSelectorHandler(tu.Handler):
 
     def close(self, info, is_ok):
-        # Removes the span selector from the plot
-        info.object.span_selector_switch(False)
         if is_ok is True:
             self.apply(info)
+
+        # Removes the span selector from the plot
+        info.object.span_selector_switch(False)
+
         return True
 
     def apply(self, info, *args, **kwargs):
@@ -70,11 +109,16 @@ class Signal1DRangeSelectorHandler(tu.Handler):
 
         """
         obj = info.object
-        if obj.ss_left_value != obj.ss_right_value:
-            info.object.span_selector_switch(False)
-            for method, cls in obj.on_close:
-                method(cls, obj.ss_left_value, obj.ss_right_value)
-            info.object.span_selector_switch(True)
+        extents = obj.span_selector.extents
+        # when the traits and span extent are out of sync, which happen after
+        # "apply" and before making a new selection
+        if obj.ss_left_value == obj.ss_right_value or extents[0] == extents[1]:
+            return
+
+        obj.span_selector_switch(False)
+        for method, cls in obj.on_close:
+            method(cls, obj.ss_left_value, obj.ss_right_value)
+        obj.span_selector_switch(True)
 
         obj.is_ok = True
 
@@ -92,6 +136,16 @@ class CalibrationHandler(SpanSelectorInSignal1DHandler):
         return
 
 
+class Calibration2DHandler(LineSelectorInSignal2DHandler):
+    def apply(self, info, *args, **kwargs):
+        """Handles the **Apply** button being clicked."""
+        if info.object.signal is None:
+            return
+        info.object.apply()
+        self.close_directly(info)
+        return
+
+
 class ImageContrastHandler(tu.Handler):
 
     def close(self, info, is_ok):
@@ -161,6 +215,23 @@ def calibration_traitsui(obj, **kwargs):
     return obj, {"view": view}
 
 
+@add_display_arg
+def calibration2d_traitsui(obj, **kwargs):
+    view = tu.View(
+        tu.Group(
+            "new_length",
+            tu.Item("length", label="Current length", style="readonly"),
+            tu.Item(name="scale", style="readonly"),
+            "units",
+        ),
+        handler=Calibration2DHandler,
+        buttons=[OurApplyButton, CancelButton],
+        kind="live",
+        title="Calibration parameters",
+    )
+    return obj, {"view": view}
+
+
 @add_display_arg
 def interactive_range_selector(obj, **kwargs):
     spanner_items = get_spanner_left_right_items()
@@ -247,7 +318,8 @@ def smooth_butterworth(obj, **kwargs):
 @add_display_arg
 def load(obj, **kwargs):
     view = tu.View(
-        tu.Group('filename', "lazy"),
+        tu.Group(tu.Item('filename', editor=tu.FileEditor(dialog_style='open')),
+                  "lazy"),
         kind='livemodal',
         buttons=[OKButton, CancelButton],
         title='Load file')
@@ -257,6 +329,14 @@ def load(obj, **kwargs):
 @add_display_arg
 def image_constast_editor_traitsui(obj, **kwargs):
     from traitsui.qt4.extra.bounds_editor import BoundsEditor
+    
+    # format has been deprecated in Release 7.3.0, replaced by format_str
+    # https://github.com/enthought/traitsui/pull/1684
+    # Remove and simplify when minimum traitsui version is 7.3.0
+    FORMAT_STR = 'format' if Version(traitsui.__version__) < Version('7.0.0') \
+        else 'format_str'
+    def get_format_dict(formatting):
+        return {FORMAT_STR:formatting}
 
     view = tu.View(
         tu.Group(
@@ -284,7 +364,8 @@ def image_constast_editor_traitsui(obj, **kwargs):
                     editor=BoundsEditor(
                         low_name='vmin_percentile',
                         high_name='vmax_percentile',
-                        format='%.2f')),
+                        **get_format_dict('%.2f'),
+                        )),
             show_border=True,
             ),
         tu.Group(
@@ -302,8 +383,9 @@ def image_constast_editor_traitsui(obj, **kwargs):
                     visible_when='norm == "Power"',
                     editor=tu.RangeEditor(low=0.1,
                                           high=3.,
-                                          format='%.3f',
-                                          mode="slider"),
+                                          mode="slider",
+                                          **get_format_dict('%.2f'),
+                                          ),
                     ),
             tu.Item('linthresh',
                     label='Linear threshold',
@@ -311,8 +393,9 @@ def image_constast_editor_traitsui(obj, **kwargs):
                     visible_when='norm == "Symlog"',
                     editor=tu.RangeEditor(low=0.01,
                                           high=1.,
-                                          format='%.3f',
-                                          mode="slider"),
+                                          mode="slider",
+                                          **get_format_dict('%.2f'),
+                                          ),
                     ),
             tu.Item('linscale',
                     label='Linear scale',
@@ -320,8 +403,9 @@ def image_constast_editor_traitsui(obj, **kwargs):
                     visible_when='norm == "Symlog"',
                     editor=tu.RangeEditor(low=0.,
                                           high=10.,
-                                          format='%.3f',
-                                          mode="slider"),
+                                          mode="slider",
+                                          **get_format_dict('%.2f'),
+                                          ),
                     ),
             show_border=True,
             ),
